@@ -113,6 +113,14 @@ Magick::OrientationType Orientation(const char * str){
   return (Magick::OrientationType) val;
 }
 
+Magick::StyleType FontStyle(const char * str){
+  ssize_t val = MagickCore::ParseCommandOption(
+    MagickCore::MagickStyleOptions, Magick::MagickFalse, str);
+  if(val < 0)
+    throw std::runtime_error(std::string("Invalid StyleType value: ") + str);
+  return (Magick::StyleType) val;
+}
+
 #if MagickLibVersion >= 0x700
 Magick::Point Point(const char * str){
   Magick::Point point(str);
@@ -173,13 +181,19 @@ XPtrImage magick_image_emboss( XPtrImage input, const double radius = 1, const d
 }
 
 // [[Rcpp::export]]
-XPtrImage magick_image_fill( XPtrImage input, const char * color, const char * point, double fuzz_percent){
+XPtrImage magick_image_fill( XPtrImage input, const char * color, const char * point,
+                             double fuzz_percent, Rcpp::CharacterVector border_color){
   XPtrImage output = copy(input);
   double fuzz = fuzz_pct_to_abs(fuzz_percent);
   if(fuzz != 0)
     for_each ( output->begin(), output->end(), Magick::colorFuzzImage( fuzz ));
-  for_each ( output->begin(), output->end(), Magick::floodFillColorImage(
-      Magick::Geometry(Geom(point)), Color(color)));
+  if(border_color.size()){
+    for_each ( output->begin(), output->end(), Magick::floodFillColorImage(
+        Magick::Geometry(Geom(point)), Color(color), Color(border_color[0])));
+  } else {
+    for_each ( output->begin(), output->end(), Magick::floodFillColorImage(
+        Magick::Geometry(Geom(point)), Color(color)));
+  }
   if(fuzz != 0)
     for_each ( output->begin(), output->end(), Magick::colorFuzzImage(input->front().colorFuzz()));
   return output;
@@ -213,13 +227,16 @@ XPtrImage magick_image_implode( XPtrImage input, double factor){
 
 // [[Rcpp::export]]
 XPtrImage magick_image_format( XPtrImage input, Rcpp::CharacterVector format, Rcpp::CharacterVector type,
-                               Rcpp::CharacterVector space, Rcpp::IntegerVector depth, Rcpp::LogicalVector antialias){
+                               Rcpp::CharacterVector space, Rcpp::IntegerVector depth, Rcpp::LogicalVector antialias,
+                               Rcpp::LogicalVector matte){
   XPtrImage output = copy(input);
   if(antialias.size()){
     for (Iter it = output->begin(); it != output->end(); ++it)
       it->strokeAntiAlias(antialias.at(0));
     for_each ( output->begin(), output->end(), Magick::myAntiAliasImage(antialias.at(0)));
   }
+  if(matte.size())
+    for_each ( output->begin(), output->end(), Magick::myMatteImage(matte.at(0)));
   if(type.size())
     for_each ( output->begin(), output->end(), Magick::typeImage(Type(type.at(0))));
   if(space.size())
@@ -286,10 +303,10 @@ XPtrImage magick_image_reducenoise( XPtrImage input, const size_t radius){
  */
 
 // [[Rcpp::export]]
-XPtrImage magick_image_annotate( XPtrImage input, const std::string text, const char * gravity,
+XPtrImage magick_image_annotate( XPtrImage input, Rcpp::CharacterVector text, const char * gravity,
                                  const char * location, double rot, double size, const char * font,
-                                 Rcpp::CharacterVector color, Rcpp::CharacterVector strokecolor,
-                                 Rcpp::CharacterVector boxcolor){
+                                 const char * style, double weight, Rcpp::CharacterVector color,
+                                 Rcpp::CharacterVector strokecolor, Rcpp::CharacterVector boxcolor){
   XPtrImage output = copy(input);
   typedef std::container<Magick::Drawable> drawlist;
   Magick::Geometry pos(location);
@@ -305,16 +322,26 @@ XPtrImage magick_image_annotate( XPtrImage input, const std::string text, const
   if(boxcolor.size())
     draw.push_back(Magick::DrawableTextUnderColor(Color(boxcolor[0])));
   draw.push_back(Magick::DrawablePointSize(size));
-  draw.push_back(Magick::DrawableFont(normalize_font(font), Magick::NormalStyle, 400, Magick::NormalStretch));
+  draw.push_back(Magick::DrawableFont(normalize_font(font), FontStyle(style), weight, Magick::NormalStretch));
   if(rot){
     //temorary move center for rotation and then back
     draw.push_back(Magick::DrawableTranslation(x, y));
     draw.push_back(Magick::DrawableRotation(rot));
     draw.push_back(Magick::DrawableTranslation(-x, -y));
   }
-
-  draw.push_back(Magick::DrawableText(x, y, text, "UTF-8"));
-  for_each (output->begin(), output->end(), Magick::drawImage(draw));
+  int len = text.size();
+  if(len == 1){
+    draw.push_back(Magick::DrawableText(x, y, std::string(text[0]), "UTF-8"));
+    for_each (output->begin(), output->end(), Magick::drawImage(draw));
+  } else if(len > 1){
+    for(size_t i = 0; i < output->size(); i++){
+      draw.push_back(Magick::DrawableText(x, y, std::string(text[i % len]), "UTF-8"));
+      output->at(i).draw(draw);
+      draw.pop_back();
+    }
+  } else {
+    throw std::runtime_error("Length of 'text' must be equal to images or 1");
+  }
   return output;
 }
 
@@ -337,3 +364,4 @@ XPtrImage magick_image_compare( XPtrImage input, XPtrImage reference_image, cons
   return output;
 #endif
 }
+
